FLTK logo

[master] 86a0a28 - Fix comments and remove a 'todo' item from docs

FLTK matrix user chat room
(using Element browser app)   FLTK gitter user chat room   GitHub FLTK Project   FLTK News RSS Feed  
  FLTK Apps      FLTK Library      Forums      Links     Login 
 All Forums  |  Back to fltk.commit  ]
 
Previous Message ]Next Message ]

[master] 86a0a28 - Fix comments and remove a 'todo' item from docs "Albrecht Schlosser" Jan 28, 2023  
 
commit 86a0a288152da0d3891ae67f56fd88014f6787f5
Author:     Albrecht Schlosser <albrechts.fltk@online.de>
AuthorDate: Sat Jan 28 16:09:54 2023 +0100
Commit:     Albrecht Schlosser <albrechts.fltk@online.de>
CommitDate: Sat Jan 28 16:09:54 2023 +0100

    Fix comments and remove a 'todo' item from docs
    
    Comments and docs only, no code changes.

 src/Fl_Text_Display.cxx | 6 ++----
 1 file changed, 2 insertions(+), 4 deletions(-)

diff --git src/Fl_Text_Display.cxx src/Fl_Text_Display.cxx
index 00a4e6a..a7706ac 100644
--- src/Fl_Text_Display.cxx
+++ src/Fl_Text_Display.cxx
@@ -395,7 +395,7 @@ void Fl_Text_Display::buffer( Fl_Text_Buffer *buf ) {
  as-needed highlighting, triggered by a style buffer entry of
  "unfinishedStyle".  Style buffer can trigger additional redisplay during
  a normal buffer modification if the buffer contains a primary Fl_Text_Selection
- (see extendRangeForStyleMods for more information on this protocol).
+ (see extend_range_for_styles() for more information on this protocol).
 
  Style buffers, tables and their associated memory are managed by the caller.
 
@@ -423,8 +423,6 @@ void Fl_Text_Display::buffer( Fl_Text_Buffer *buf ) {
  \param cbArg an optional argument for the callback above, usually a pointer
    to the Text Display.
 
- \todo  "extendRangeForStyleMods" does not exist (might be a hangover
-         from the port from nedit). Find the correct function.
  \see Fl_Text_Display::style_buffer()
  */
 void Fl_Text_Display::highlight_data(Fl_Text_Buffer *styleBuffer,
@@ -1760,7 +1758,7 @@ void Fl_Text_Display::buffer_modified_cb( int pos, int nInserted, int nDeleted,
   /* If the changes caused scrolling, re-paint everything and we're done. */
   if ( scrolled ) {
     textD->damage(FL_DAMAGE_EXPOSE);
-    if ( textD->mStyleBuffer )   /* See comments in extendRangeForStyleMods */
+    if ( textD->mStyleBuffer )   /* See comments in extend_range_for_styles() */
       textD->mStyleBuffer->primary_selection()->selected(0);
     return;
   }
Direct Link to Message ]
 
     
Previous Message ]Next Message ]
 
 

Comments are owned by the poster. All other content is copyright 1998-2024 by Bill Spitzak and others. This project is hosted by The FLTK Team. Please report site problems to 'erco@seriss.com'.